/*
 * Copyright 1994, 1995 Vectaport Inc., Cartoactive Systems
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the names of the copyright holders not be used in
 * advertising or publicity pertaining to distribution of the software
 * without specific, written prior permission.  The copyright holders make
 * no representations about the suitability of this software for any purpose.
 * It is provided "as is" without express or implied warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 */

/* map library object */

#ifndef maplib_h
#define maplib_h

#include <Map/mapfiles.h>

class MapDatabase;
class MapCoverage;
class ostream;

class MapLibrary  : public MapFiles {
protected:
    MapLibrary(MapDatabase*, const char* name);

public:
    virtual ~MapLibrary();

    virtual const char* path() const;
    MapDatabase* database() const { return _database; }
    virtual void database(MapDatabase* db) { _database = db; }

    int ncovs() const;
    MapCoverage* coverage(unsigned covnum) const;
    MapCoverage* coverage(const char*) const;

    virtual const char* description() const;
    friend ostream& operator << (ostream& s, const MapLibrary&);

    virtual boolean tiled();
protected:
    void init_coverages();
    boolean initialized() const { return _ncovs>=0; }

    virtual char** coverage_names(int &ncovs) const = 0;
    virtual MapCoverage* make_coverage(const char* name) = 0;

    void tiled(boolean);
protected:
    MapDatabase* _database;

    int _ncovs;
    MapCoverage** _coverages;
    boolean _tiled;
};

#endif /* defined(maplib_h) */
